---
title: Loss functions
---

::: klax.Loss
    options:
        members:
            - __call__

---

::: klax.MSE
    options:
        members:
            - __call__


::: klax.mse

---

::: klax.MAE
    options:
        members:
            - __call__


::: klax.mae